package opencloudos9

import (
	"github.com/osbuild/osbuild-composer/internal/common"
	"github.com/osbuild/osbuild-composer/internal/distro"
	"github.com/osbuild/osbuild-composer/internal/osbuild"
	"github.com/osbuild/osbuild-composer/internal/rpmmd"
)

var vmdkImgType = imageType{
	name:     "vmdk",
	filename: "disk.vmdk",
	mimeType: "application/x-vmdk",
	packageSets: map[string]packageSetFunc{
		osPkgsKey: vmdkCommonPackageSet,
	},
	defaultImageConfig: &distro.ImageConfig{
		Locale: common.ToPtr("en_US.UTF-8"),
		Grub2Config: &osbuild.GRUB2Config{
			Timeout: 5,
		},
	},
	kernelOptions:       "ro",
	bootable:            true,
	defaultSize:         4 * common.GibiByte,
	image:               liveImage,
	buildPipelines:      []string{"build"},
	payloadPipelines:    []string{"os", "image", "vmdk"},
	exports:             []string{"vmdk"},
	basePartitionTables: defaultBasePartitionTables,
}

func vmdkCommonPackageSet(t *imageType) rpmmd.PackageSet {
	ps := rpmmd.PackageSet{
		Include: []string{
			"chrony",
			"firewalld",
		},
	}.Append(bootPackageSet(t)).Append(coreOsCommonPackageSet(t))

	if t.arch.Name() == distro.X86_64ArchName {
		ps = ps.Append(rpmmd.PackageSet{
			Include: []string{
				// packages below used to come from @core group and were not excluded
				// they may not be needed at all, but kept them here to not need
				// to exclude them instead in all other images
				"linux-firmware-iwlwifi",
			},
		})
	}

	return ps
}
